function [results, op_names] = get_results( this, op_name, vars )

% Use method get_res instead of this!!!
%
% [results, [op_names] ] = get_results( this, [op_name, [vars]] )
%
% this       stats object that is used for recording the measurements
% op_name    name of the operation. if omitted, then all results
%            are returned in a 1d cell array and 'op_names' is filled
%            with the corresponding op_names in a 1d cell array
% vars       only variables listed in this cell struct (by name)
%            are returned as a table, ie. other result columns are deleted. If
%            omitted, a struct will be returned. See below.
%
% If 'vars' is omitted, a struct or structs containing the results is returned.
% The data structure of the results is defined in file @stats/stats.m
% If op_name is specified, then 'results' will contain the
% corresponding struct, otherwise 'results' will contain cell array
% of structs and 'op_names' will contain their names. The
% operations are listed in same order that the 'info' method uses.
%
% If 'vars' is specified, then a table containing results from
% 'op_name' is returned. Each column represents a variable
% specified in 'vars' in corresponding order.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


switch nargin
  
 case 1
  
  % Return all results
  results = this.results;
  op_names = this.result_names;
  return;
  
 case 2
  
  % Return only one result
  op_index = find( strcmp( this.result_names, op_name ) );
  if isempty( op_index ), error([ 'Unknown operation: ' op_name ]); end
  results = this.results{op_index};
  return;
  
 case 3
  
  % Return variables 'vars' from operation 'op_name'
  all_res   = get_results( this, op_name );
  var_names = get_var_names( this, op_name );
  if ~isempty( all_res )
    for col = 1 : length( vars )
      var_col = find( strcmp( var_names, vars{col} ) );
      if isempty( var_col )
        error([ 'Unknown variable ' vars{col} ' for operation ' op_name ]);
      end
      results(:,col) = all_res( :, var_col );
    end
  else
    results = [];
  end
  return;
  
end
