function object = trigger_stationary( count, input )

% object = trigger_stationary( count, input )
%
% Triggers when the input has not changed for a 'count' consecutive samples. If
% the input contains multiple channels, then count can be either a single value
% and the trigger requires that each channel stays stationary for that period,
% or it can be a vector of equal length with the channel count to define
% individual periods for each channel.
%
% A 'count' of 1 means that the input must stay stationary for two consecutive
% samples. The 'count' must always be >= 1.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% define the class so that matlab recognizes it when loading objects
if nargin == 0
  this.enabled     = [];
  this.counts      = [];
  this.last_vals   = [];
  this.max_counts  = [];
  this.input       = [];
  this.level       = [];
  object = class( this, 'trigger_stationary' );
  return;
end


if length(count) == 1, count = repmat( count, 1, get_nchannels(input) ); end
if any(count<1), error('''count'' must always be >= 1!'); end


this.enabled     = 0;
this.counts      = [];
this.last_vals   = [];
this.max_counts  = count;
this.input       = input;
this.level       = 0;


object = class( this, 'trigger_stationary' );
return;
