function Improve_model( ind, s, caller )

% Improve_model( ind, settings, [caller] )
%
% IVGA primitive operation. Recorded properties:
%   cputimer, cputime, total cost, stop trigger level
%
% ind      index of the group to be tuned
% s        settings
% caller   caller's name. it will be added to the end of the operation's name
%          when recording stats.
%
% settings, valid fields:
%   .stop_trigger
%
% Improves the specified model according to given settings.
% Tuning is stopped when the given trigger activates (reaches value 1). The
% improvement iteration is controlled in this function, and the model's
% support method should execute only in short leaps.
%
% Note: Calling this function for a non-precomputed model will cause the
% model to be reconstructed!


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global STATS State;


% choose operation name
op_name = 'Improve_model';
if exist('caller', 'var'), op_name = [caller ' - ' op_name]; end

% copy and enable the stop trigger.
stop_trigger = set_enabled( s.stop_trigger, 1 );


% improve until the stop trigger activates
STATS = measure( STATS, op_name, 'start', State, 0 );
[stop_trigger, trigger_level] = get_level( stop_trigger );
while trigger_level < 1
  
  % tune the model
  State.Groups(ind).Model = improve( State.Groups(ind).Model );
  
  % record progress and read stop trigger level
  STATS = measure(STATS, op_name, 'checkpoint', State, trigger_level);
  [stop_trigger, trigger_level] = get_level( stop_trigger );
  
end
STATS = measure( STATS, op_name, 'stop', State, trigger_level );


return;
